@@ -1,6 +1,6 @@
 """Validate HTML5 files."""
 
-__version__ = "0.1.2"
+__version__ = "0.1.3"
 
 import os
 import sys
@@ -8,6 +8,12 @@ import fnmatch
 import subprocess
 
 
+class JavaNotFoundException(Exception):
+    def __str__(self):
+        return 'Missing Java Runtime Environment on this system. ' +\
+               'The command "java" must be available.'
+
+
 class Validator(object):
 
     def __init__(self, directory='.', match='*.html', blacklist=[]):
@@ -31,10 +37,11 @@ class Validator(object):
         if errors_only:
             opts.append('--errors-only')
         files = self.all_files()
-        try:
-            subprocess.check_output(['java', '-jar', self.vnu_jar_location] +
-                                    opts + files)
-        except subprocess.CalledProcessError:
-            print '===> Not HTML5 compatible.'
-            return 1
-        return 0
+
+        with open(os.devnull, 'w') as f_null:
+            if subprocess.call(['java', '-version'],
+                               stdout=f_null, stderr=f_null) != 0:
+                raise JavaNotFoundException()
+
+        return subprocess.call(['java', '-jar', self.vnu_jar_location] +
+                               opts + files)
