@@ -1,4 +1,5 @@
-"""Command line tool for HTML5 validation."""
+#!/usr/bin/env python
+"""Command line tool for HTML5 validation. Return code is 0 for valid HTML5."""
 
 import sys
 import argparse
